# CALICOlib
CALICOlib is a framework to help facilitate problem creation on DOMjudge. Currently, the library helps with test generation and creating problem zip, which is based on the ICPC problem package specification

## Quick Start


## Similar tools
https://github.com/RagnarGrootKoerkamp/BAPCtools
